/*
 * parser-sming.h --
 *
 *      Definition for the SMIv1/v2 parser.
 *
 * Copyright (c) 1999 Frank Strauss, Technical University of Braunschweig.
 *
 * See the file "COPYING" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 * @(#) $Id: parser-sming.h 1736 2011-12-14 14:06:39Z schoenw $
 */

#ifndef _PARSER_SMING_H
#define _PARSER_SMING_H

#include <stdio.h>

#include "smi-data.h"



#define YYERROR_VERBOSE



extern int smingparse();



#endif /* _PARSER_SMING_H */

